#
# spec file for package python-portpicker
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-portpicker
Version:        1.5.2
Release:        1.5
Summary:        A library to choose unique available network ports
License:        Apache-2.0
Group:          Development/Libraries/Python
URL:            https://github.com/google/python_portpicker
Source0:        https://files.pythonhosted.org/packages/source/p/portpicker/portpicker-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
# /SECTION
%python_subpackages

%description
Portpicker provides an API to find and return an available network port for
an application to bind to. Ideally suited for use from unittests or for test
harnesses that launch local servers.

%prep
%setup -q -n portpicker-%{version}
test -f setup.py || echo "import setuptools; setuptools.setup()" > setup.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/portserver.py
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} $python src/tests/portpicker_test.py

%post
%python_install_alternative portserver.py

%postun
%python_uninstall_alternative portserver.py

%files %{python_files}
%license LICENSE
%doc CONTRIBUTING.md README.md
%{python_sitelib}/*
# import asyncio
%python_alternative %{_bindir}/portserver.py

%changelog
* Tue Jul 19 2022 Dirk Müller <dmueller@suse.com>
- update to 1.5.2:
  * Do not re-pick a known used (not-yet-returned) port when running stand alone
    without a portserver.
  * When not using a portserver *(you really should)*, try the `bind(0)`
    approach before hunting for random unused ports. More reliable per
* Wed Apr  6 2022 pgajdos@suse.com
- python-mock is not required for build
* Sun Jan 16 2022 Dirk Müller <dmueller@suse.com>
- update to to 1.5.0:
  * python 3.10 support
* Mon May 18 2020 Matej Cepl <mcepl@suse.com>
- Don't use %%python3_only command, but properly use alternatives.
* Mon May 20 2019 pgajdos@suse.com
- version update to 1.3.1
  * Fix a race condition in `pick_unused_port()` involving the free ports set.
  * Adds an optional `portserver_address` parameter to `pick_unused_port()` so
    that callers can specify their own regardless of `os.environ`.
  * `pick_unused_port()` now raises `NoFreePortFoundError` when no available port
    could be found rather than spinning in a loop trying forever.
  * Fall back to `socket.AF_INET` when `socket.AF_UNIX` support is not available
    to communicate with a portserver.
  * Introduced `add_reserved_port()` and `return_port()` APIs to allow ports to
    be recycled and allow users to bring ports of their own.
  * Changed default port range to 15000-24999 to avoid ephemeral ports.
  * Portserver bugfix.
- convert to single spec
- run test
* Tue Dec  1 2015 rjschwei@suse.com
- Include in SLE 12 (FATE#319904, bsc#954690)
* Thu Nov 12 2015 rjschwei@suse.com
- Initial build
  + Version 1.1.0
